@@ -54,7 +54,7 @@ $RCPROG $INITSCRIPT stop
 
 INSTALL="install -o root -g root"
 
-mkdir -p /etc/laptop-mode /etc/laptop-mode/batt-start /etc/laptop-mode/batt-stop /etc/laptop-mode/lm-ac-start /etc/laptop-mode/lm-ac-stop /etc/laptop-mode/nolm-ac-start /etc/laptop-mode/nolm-ac-stop
+mkdir -p /etc/laptop-mode /etc/laptop-mode/batt-start /etc/laptop-mode/batt-stop /etc/laptop-mode/lm-ac-start /etc/laptop-mode/lm-ac-stop /etc/laptop-mode/nolm-ac-start /etc/laptop-mode/nolm-ac-stop /usr/lib/laptop-mode-tools/modules /etc/laptop-mode/conf.d /etc/laptop-mode/modules
 
 ALREADY_EXISTED=0
 
@@ -66,13 +66,6 @@ elif ( ! $INSTALL -m 600 etc/laptop-mode/laptop-mode.conf /etc/laptop-mode ) ; t
 	exit 12
 fi
 
-mkdir -p /etc/laptop-mode/nolm-ac-start
-mkdir -p /etc/laptop-mode/nolm-ac-stop
-mkdir -p /etc/laptop-mode/lm-ac-start
-mkdir -p /etc/laptop-mode/lm-ac-stop
-mkdir -p /etc/laptop-mode/batt-start
-mkdir -p /etc/laptop-mode/batt-stop
-
 if [ -f /etc/default/laptop-mode -a "$ALREADY_EXISTED" -eq 0 ] ; then
         echo "Found old configuration file in /etc/default/laptop-mode. Moving to the new location."
 	if ( ! mv /etc/default/laptop-mode /etc/laptop-mode/laptop-mode.conf ) ; then
@@ -88,6 +81,15 @@ if [ -f /etc/sysconfig/laptop-mode -a "$ALREADY_EXISTED" -eq 0 ] ; then
 	fi
 fi
 
+for CONF in etc/laptop-mode/conf.d/* ; do
+	if [ -f /"$CONF" ] ; then
+		echo "Not reinstalling configuration file /$CONF."
+	elif ( ! $INSTALL -m 600 "$CONF" /"$CONF" ) ; then
+		echo "$0: Failed to install configuration file /$CONF. Installation failed."
+		exit 12
+	fi
+done
+
 
 if [ -f /etc/laptop-mode/lm-profiler.conf ] ; then
 	echo "Configuration file /etc/laptop-mode/lm-profiler.conf already exists."
@@ -112,6 +114,20 @@ if ( ! $INSTALL -m 700 usr/sbin/lm-profiler /usr/sbin ) ; then
 	exit 11
 fi
 
+if ( ! $INSTALL -m 700 usr/lib/laptop-mode-tools/modules/* /usr/lib/laptop-mode-tools/modules ) ; then
+	echo "$0: Failed to install modules into /usr/lib/laptop-mode-tools/modules. Installation failed."
+	exit 26
+fi
+
+if ( ! mkdir -p $MAN_D ) ; then
+  echo "$0: Could not create directory $MAN_D. Installation failed."
+  exit 22
+fi
+if ( ! cp man/* $MAN_D ) ; then
+  echo "$0: Could not copy manual pages to $MAN_D. Installation failed."
+  exit 23
+fi
+
 ACPI_DONE=0
 if [ ! -d /proc/pmu -a -d /etc/acpi ] ; then
 	mkdir -p /etc/acpi/actions
